@@ -10,7 +10,6 @@ from .exceptions import JSONPathIndexError
 from .exceptions import JSONPathNameError
 from .exceptions import JSONPathSyntaxError
 from .exceptions import JSONPathTypeError
-from .exceptions import JSONPointerEncodeError
 from .exceptions import JSONPointerError
 from .exceptions import JSONPointerIndexError
 from .exceptions import JSONPointerKeyError
@@ -24,6 +23,7 @@ from .fluent_api import Projection
 from .fluent_api import Query
 from .lex import Lexer
 from .match import JSONPathMatch
+from .match import NodeList
 from .parse import Parser
 from .patch import JSONPatch
 from .path import CompoundJSONPath
@@ -51,13 +51,13 @@ __all__ = (
     "JSONPathSyntaxError",
     "JSONPathTypeError",
     "JSONPointer",
-    "JSONPointerEncodeError",
     "JSONPointerError",
     "JSONPointerIndexError",
     "JSONPointerKeyError",
     "JSONPointerResolutionError",
     "JSONPointerTypeError",
     "Lexer",
+    "NodeList",
     "match",
     "Parser",
     "Projection",
