@@ -544,7 +544,12 @@ class SelfPath(Path):
                 return context.current
             return NodeList()
 
-        return NodeList(self.path.finditer(context.current))
+        return NodeList(
+            self.path.finditer(
+                context.current,
+                filter_context=context.extra_context,
+            )
+        )
 
     async def evaluate_async(self, context: FilterContext) -> object:
         if isinstance(context.current, str):  # TODO: refactor
@@ -557,7 +562,13 @@ class SelfPath(Path):
             return NodeList()
 
         return NodeList(
-            [match async for match in await self.path.finditer_async(context.current)]
+            [
+                match
+                async for match in await self.path.finditer_async(
+                    context.current,
+                    filter_context=context.extra_context,
+                )
+            ]
         )
 
 
@@ -576,11 +587,22 @@ class RootPath(Path):
         return str(self.path)
 
     def evaluate(self, context: FilterContext) -> object:
-        return NodeList(self.path.finditer(context.root))
+        return NodeList(
+            self.path.finditer(
+                context.root,
+                filter_context=context.extra_context,
+            )
+        )
 
     async def evaluate_async(self, context: FilterContext) -> object:
         return NodeList(
-            [match async for match in await self.path.finditer_async(context.root)]
+            [
+                match
+                async for match in await self.path.finditer_async(
+                    context.root,
+                    filter_context=context.extra_context,
+                )
+            ]
         )
 
 
@@ -600,13 +622,21 @@ class FilterContextPath(Path):
         return "_" + path_repr[1:]
 
     def evaluate(self, context: FilterContext) -> object:
-        return NodeList(self.path.finditer(context.extra_context))
+        return NodeList(
+            self.path.finditer(
+                context.extra_context,
+                filter_context=context.extra_context,
+            )
+        )
 
     async def evaluate_async(self, context: FilterContext) -> object:
         return NodeList(
             [
                 match
-                async for match in await self.path.finditer_async(context.extra_context)
+                async for match in await self.path.finditer_async(
+                    context.extra_context,
+                    filter_context=context.extra_context,
+                )
             ]
         )
 
